@@ -9,10 +9,11 @@ from django.contrib.admin.utils import model_ngettext
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import PermissionDenied
 from django.template.response import TemplateResponse
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.html import conditional_escape, format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
+from .config import FIELD_NAME
 from .utils import related_objects
 
 # Django 3.0 compatibility
@@ -27,7 +28,7 @@ def highlight_deleted(obj):
         Display in red lines when object is deleted.
     """
     obj_str = conditional_escape(text_type(obj))
-    if not getattr(obj, 'deleted', False):
+    if not getattr(obj, FIELD_NAME, False):
         return obj_str
     else:
         return format_html('<span class="deleted">{0}</span>', obj_str)
@@ -49,9 +50,9 @@ class SafeDeleteAdmin(admin.ModelAdmin):
     """
     undelete_selected_confirmation_template = "safedelete/undelete_selected_confirmation.html"
 
-    list_display = ('deleted',)
-    list_filter = ('deleted',)
-    exclude = ('deleted',)
+    list_display = (FIELD_NAME,)
+    list_filter = (FIELD_NAME,)
+    exclude = (FIELD_NAME,)
     actions = ('undelete_selected',)
 
     class Meta:
@@ -69,7 +70,7 @@ class SafeDeleteAdmin(admin.ModelAdmin):
     def get_queryset(self, request):
         try:
             queryset = self.model.all_objects.all()
-        except:
+        except Exception:
             queryset = self.model._default_manager.all()
 
         ordering = self.get_ordering(request)
@@ -99,16 +100,16 @@ class SafeDeleteAdmin(admin.ModelAdmin):
         assert hasattr(queryset, 'undelete')
 
         # Remove not deleted item from queryset
-        queryset = queryset.filter(deleted__isnull=False)
+        queryset = queryset.filter(**{FIELD_NAME + '__isnull': False})
         # Undeletion confirmed
         if request.POST.get('post'):
             requested = queryset.count()
             if requested:
                 for obj in queryset:
-                    obj_display = force_text(obj)
+                    obj_display = force_str(obj)
                     self.log_undeletion(request, obj, obj_display)
                 queryset.undelete()
-                changed = original_queryset.filter(deleted__isnull=True).count()
+                changed = original_queryset.filter(**{FIELD_NAME + '__isnull': True}).count()
                 if changed < requested:
                     self.message_user(
                         request,
@@ -134,9 +135,9 @@ class SafeDeleteAdmin(admin.ModelAdmin):
 
         opts = self.model._meta
         if len(queryset) == 1:
-            objects_name = force_text(opts.verbose_name)
+            objects_name = force_str(opts.verbose_name)
         else:
-            objects_name = force_text(opts.verbose_name_plural)
+            objects_name = force_str(opts.verbose_name_plural)
         title = _("Are you sure?")
 
         related_list = [list(related_objects(obj)) for obj in queryset]
