@@ -1,7 +1,8 @@
 from django.conf import settings
 from django.db import models
 
-from .config import DELETED_INVISIBLE, DELETED_ONLY_VISIBLE, DELETED_VISIBLE, SOFT_DELETE, SOFT_DELETE_CASCADE
+from .config import DELETED_INVISIBLE, DELETED_ONLY_VISIBLE, DELETED_VISIBLE, SOFT_DELETE, SOFT_DELETE_CASCADE, \
+    FIELD_NAME
 from .queryset import SafeDeleteQueryset
 
 
@@ -57,8 +58,8 @@ class SafeDeleteManager(models.Manager):
     def get_queryset(self):
         # Backwards compatibility, no need to move options to QuerySet.
         queryset = self._queryset_class(self.model, using=self._db)
-        queryset._safedelete_visibility = self._safedelete_visibility
-        queryset._safedelete_visibility_field = self._safedelete_visibility_field
+        queryset.query._safedelete_visibility = self._safedelete_visibility
+        queryset.query._safedelete_visibility_field = self._safedelete_visibility_field
         return queryset
 
     def all_with_deleted(self):
@@ -98,7 +99,7 @@ class SafeDeleteManager(models.Manager):
         # We don't call all() on the queryset, see https://github.com/makinacorpus/django-safedelete/issues/81
         qs = self.get_queryset()
         if force_visibility is not None:
-            qs._safedelete_force_visibility = force_visibility
+            qs.query._safedelete_force_visibility = force_visibility
         return qs
 
     def update_or_create(self, defaults=None, **kwargs):
@@ -122,11 +123,11 @@ class SafeDeleteManager(models.Manager):
         revived_soft_deleted_object = False
         if self.model.has_unique_fields():
             # Check if object is already soft-deleted
-            deleted_object = self.all_with_deleted().filter(**kwargs).exclude(deleted=None).first()
+            deleted_object = self.all_with_deleted().filter(**kwargs).exclude(**{FIELD_NAME: None}).first()
 
             # If object is soft-deleted, reset delete-state...
             if deleted_object and deleted_object._safedelete_policy in self.get_soft_delete_policies():
-                deleted_object.deleted = None
+                setattr(deleted_object, FIELD_NAME, None)
                 deleted_object.save()
                 revived_soft_deleted_object = True
 
@@ -142,7 +143,7 @@ class SafeDeleteManager(models.Manager):
 
     @staticmethod
     def get_soft_delete_policies():
-        """Returns all stati which stand for some kind of soft-delete"""
+        """Returns all states which stand for some kind of soft-delete"""
         return [SOFT_DELETE, SOFT_DELETE_CASCADE]
 
 
