@@ -1,10 +1,11 @@
 import warnings
 
+from django.contrib.admin.utils import NestedObjects
 from django.db import models, router
 from django.utils import timezone
 
 from .config import (HARD_DELETE, HARD_DELETE_NOCASCADE, NO_DELETE,
-                     SOFT_DELETE, SOFT_DELETE_CASCADE)
+                     SOFT_DELETE, SOFT_DELETE_CASCADE, FIELD_NAME)
 from .managers import (SafeDeleteAllManager, SafeDeleteDeletedManager,
                        SafeDeleteManager)
 from .signals import post_softdelete, post_undelete, pre_softdelete
@@ -62,8 +63,6 @@ class SafeDeleteModel(models.Model):
 
     _safedelete_policy = SOFT_DELETE
 
-    deleted = models.DateTimeField(editable=False, null=True)
-
     objects = SafeDeleteManager()
     all_objects = SafeDeleteAllManager()
     deleted_objects = SafeDeleteDeletedManager()
@@ -90,9 +89,9 @@ class SafeDeleteModel(models.Model):
 
         was_undeleted = False
         if not keep_deleted:
-            if self.deleted and self.pk:
+            if getattr(self, FIELD_NAME) and self.pk:
                 was_undeleted = True
-            self.deleted = None
+            setattr(self, FIELD_NAME, None)
 
         super(SafeDeleteModel, self).save(**kwargs)
 
@@ -113,15 +112,19 @@ class SafeDeleteModel(models.Model):
         """
         current_policy = force_policy or self._safedelete_policy
 
-        assert self.deleted
+        assert getattr(self, FIELD_NAME)
         self.save(keep_deleted=False, **kwargs)
 
         if current_policy == SOFT_DELETE_CASCADE:
             for related in related_objects(self):
-                if is_safedelete_cls(related.__class__) and related.deleted:
+                if is_safedelete_cls(related.__class__) and getattr(related, FIELD_NAME):
                     related.undelete()
 
     def delete(self, force_policy=None, **kwargs):
+        # To know why we need to do that, see https://github.com/makinacorpus/django-safedelete/issues/117
+        self._delete(force_policy, **kwargs)
+
+    def _delete(self, force_policy=None, **kwargs):
         """Overrides Django's delete behaviour based on the model's delete policy.
 
         Args:
@@ -131,50 +134,71 @@ class SafeDeleteModel(models.Model):
         current_policy = self._safedelete_policy if (force_policy is None) else force_policy
 
         if current_policy == NO_DELETE:
-
             # Don't do anything.
             return
-
         elif current_policy == SOFT_DELETE:
-
-            # Only soft-delete the object, marking it as deleted.
-            self.deleted = timezone.now()
-            using = kwargs.get('using') or router.db_for_write(self.__class__, instance=self)
-            # send pre_softdelete signal
-            pre_softdelete.send(sender=self.__class__, instance=self, using=using)
-            self.save(keep_deleted=True, **kwargs)
-            # send softdelete signal
-            post_softdelete.send(sender=self.__class__, instance=self, using=using)
-
+            self.soft_delete_policy_action(**kwargs)
         elif current_policy == HARD_DELETE:
-
-            # Normally hard-delete the object.
-            super(SafeDeleteModel, self).delete()
-
+            self.hard_delete_policy_action(**kwargs)
         elif current_policy == HARD_DELETE_NOCASCADE:
-
-            # Hard-delete the object only if nothing would be deleted with it
-
-            if not can_hard_delete(self):
-                self.delete(force_policy=SOFT_DELETE, **kwargs)
-            else:
-                self.delete(force_policy=HARD_DELETE, **kwargs)
-
+            self.hard_delete_cascade_policy_action(**kwargs)
         elif current_policy == SOFT_DELETE_CASCADE:
-            # Soft-delete on related objects before
-            for related in related_objects(self):
-                if is_safedelete_cls(related.__class__) and not related.deleted:
-                    related.delete(force_policy=SOFT_DELETE, **kwargs)
-            # soft-delete the object
-            self.delete(force_policy=SOFT_DELETE, **kwargs)
+            self.soft_delete_cascade_policy_action(**kwargs)
+
+    def soft_delete_policy_action(self, **kwargs):
+        # Only soft-delete the object, marking it as deleted.
+        setattr(self, FIELD_NAME, timezone.now())
+        using = kwargs.get('using') or router.db_for_write(self.__class__, instance=self)
+        # send pre_softdelete signal
+        pre_softdelete.send(sender=self.__class__, instance=self, using=using)
+        self.save(keep_deleted=True, **kwargs)
+        # send softdelete signal
+        post_softdelete.send(sender=self.__class__, instance=self, using=using)
+
+    def hard_delete_policy_action(self, **kwargs):
+        # Normally hard-delete the object.
+        super(SafeDeleteModel, self).delete()
+
+    def hard_delete_cascade_policy_action(self, **kwargs):
+        # Hard-delete the object only if nothing would be deleted with it
+        if not can_hard_delete(self):
+            self._delete(force_policy=SOFT_DELETE, **kwargs)
+        else:
+            self._delete(force_policy=HARD_DELETE, **kwargs)
+
+    def soft_delete_cascade_policy_action(self, **kwargs):
+        # Soft-delete on related objects before
+        for related in related_objects(self):
+            if is_safedelete_cls(related.__class__) and not getattr(related, FIELD_NAME):
+                related.delete(force_policy=SOFT_DELETE, **kwargs)
+
+        # soft-delete the object
+        self._delete(force_policy=SOFT_DELETE, **kwargs)
+
+        collector = NestedObjects(using=router.db_for_write(self))
+        collector.collect([self])
+        # update fields (SET, SET_DEFAULT or SET_NULL)
+        for model, instances_for_fieldvalues in collector.field_updates.items():
+            for (field, value), instances in instances_for_fieldvalues.items():
+                query = models.sql.UpdateQuery(model)
+                query.update_batch(
+                    [obj.pk for obj in instances],
+                    {field.name: value},
+                    collector.using,
+                )
 
     @classmethod
     def has_unique_fields(cls):
-        """Checks if one of the fields of this model has a unique constraint set (unique=True)
+        """Checks if one of the fields of this model has a unique constraint set (unique=True).
+
+        It also checks if the model has sets of field names that, taken together, must be unique.
 
         Args:
             model: Model instance to check
         """
+        if cls._meta.unique_together:
+            return True
+
         for field in cls._meta.fields:
             if field._unique:
                 return True
@@ -219,6 +243,9 @@ class SafeDeleteModel(models.Model):
         return errors
 
 
+SafeDeleteModel.add_to_class(FIELD_NAME, models.DateTimeField(editable=False, null=True))
+
+
 class SafeDeleteMixin(SafeDeleteModel):
     """``SafeDeleteModel`` was previously named ``SafeDeleteMixin``.
 
